<?php

namespace Drupal\Tests\widget_type\Kernel;

use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\KernelTests\KernelTestBase;
use Drupal\widget_type\Entity\WidgetRegistrySource;
use Drupal\widget_type\WidgetRegistrySourceListBuilder;

/**
 * Kernel tests for WidgetRegistrySourceListBuilder.
 *
 * @group widget_type
 * @coversDefaultClass \Drupal\widget_type\WidgetRegistrySourceListBuilder
 */
class WidgetRegistrySourceListBuilderTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'widget_type',
    'field',
    'text',
    'user',
    'system',
  ];

  /**
   * The system under test.
   *
   * @var \Drupal\widget_type\WidgetRegistrySourceListBuilder
   */
  private $theSut;

  /**
   * The entity.
   *
   * @var \Drupal\widget_type\WidgetRegistrySourceInterface
   */
  private $entity;

  /**
   * {@inheritdoc}
   *
   * @SuppressWarnings(PHPMD.StaticAccess)
   */
  protected function setUp(): void {
    parent::setUp();
    \Drupal::setContainer($this->container);
    $this->installEntitySchema('widget_type');
    $this->installEntitySchema('user');
    $this->installConfig(['field', 'widget_type', 'user']);
    $this->theSut = new WidgetRegistrySourceListBuilder(
      $this->prophesize(EntityTypeInterface::class)->reveal(),
      $this->prophesize(EntityStorageInterface::class)->reveal()
    );
    $this->entity = WidgetRegistrySource::create([
      'label' => 'The name',
      'id' => 'the-id',
      'endpoint' => 'https://www.example.org/registry.json',
      'status' => TRUE,
    ]);
    $this->entity->save();
  }

  /**
   * @covers ::buildRow
   *
   * @SuppressWarnings(PHPMD.StaticAccess)
   */
  public function testBuildRow() {
    $row = $this->theSut->buildRow($this->entity);
    self::assertSame('operations', $row['operations']['data']['#type']);
    $expected = [
      'label' => 'The name',
      'endpoint' => 'https://www.example.org/registry.json',
      'status' => 'Enabled',
    ];
    self::assertEquals($expected, array_intersect_key($row, $expected));
  }

  /**
   * @covers ::buildHeader
   */
  public function testBuildHeader() {
    self::assertEquals([
      'label' => 'Label',
      'endpoint' => 'Endpoint',
      'status' => 'Status',
      'operations' => 'Operations',
    ], array_map(function (TranslatableMarkup $markup) {
      return $markup->render();
    }, $this->theSut->buildHeader()));
  }

  /**
   * @covers ::getDefaultOperations
   */
  public function testGetDefaultOperations() {
    $operations = $this->theSut->getOperations($this->entity);
    $this->assertEquals([], $operations);
  }

}
